@@ -121,6 +121,7 @@
     ## Temporary file for 'goodLines'. Reading from this file is
     ## faster than making a textConnection to 'goodLines'.
     tf <- tempfile()
+    check.tempdir()
     tfcon <- file(tf, encoding="UTF-8")
     on.exit(close(tfcon))
     on.exit(unlink(tf), add=TRUE)
@@ -327,7 +328,7 @@
     }
     extra.col <- dat[[13]]
 
-    res <- .Call(rwl.readloop, series.index, decade.yr, x)
+    res <- .Call(dplR.readloop, series.index, decade.yr, x)
     rw.mat <- res[[1]]
     min.year <- res[[2]]
     prec.rproc <- res[[3]]
