@@ -1,10 +1,15 @@
 wavelet.plot <-
     function(wave.list,
              wavelet.levels = quantile(wave.list$Power, probs=(0:10)/10),
-             add.coi = TRUE, add.sig = TRUE, x.lab = gettext("Time"),
-             period.lab = gettext("Period"), crn.lab = gettext("RWI"),
+             add.coi = TRUE, add.sig = TRUE,
+             x.lab = gettext("Time", domain = "R-dplR"),
+             period.lab = gettext("Period", domain = "R-dplR"),
+             crn.lab = gettext("RWI", domain = "R-dplR"),
              key.cols = rev(rainbow(length(wavelet.levels)-1)),
-             key.lab = parse(text = paste0("\"", gettext("Power"), "\"^2")),
+             key.lab = parse(text = paste0("\"",
+                                           gettext("Power",
+                                                   domain = "R-dplR"),
+                                           "\"^2")),
              add.spline = FALSE, f = 0.5, nyrs = NULL,
              crn.col = "black", crn.lwd = 1,coi.col='black',
              crn.ylim = range(wave.list$y) * c(0.95, 1.05),
