@@ -1,8 +1,12 @@
 `write.crn` <- function(crn, fname, header=NULL, append=FALSE)
 {
+    stopifnot(is.data.frame(crn))
     if (ncol(crn) != 2) {
         stop("'crn' must have 2 columns")
     }
+    cnames <- names(crn)
+    stopifnot(is.character(cnames), !is.na(cnames),
+              Encoding(cnames) != "bytes")
     crn2 <- crn
 
     if (any(is.na(crn2))) {
@@ -20,16 +24,15 @@
             stop("bad idea to append with 'header'")
         }
     }
-    header2 <- header
-    if(length(header2) > 0){
-        if (!is.list(header2)) {
+    if (length(header) > 0){
+        if (!is.list(header)) {
             stop("header must be a list")
         }
         header.names <-
             c("site.id", "site.name", "spp.code", "state.country",
               "spp", "elev", "lat", "long", "first.yr", "last.yr",
               "lead.invs", "comp.date")
-        if (!all(header.names %in% names(header2))) {
+        if (!all(header.names %in% names(header))) {
             stop("'header' must be a list with the following names: ",
                  paste(dQuote(header.names), collapse = ", "))
         }
@@ -40,20 +43,15 @@
         ## Note: lat-lons are in degrees and minutes, ddmm or dddmm
         ## Record #3: 1-6 Site ID, 10-72 Lead Investigator, 73-80
         ## comp. date
-        header2 <- lapply(header2, as.character)
-        site.id <- header2$site.id[1]
-        site.name <- header2$site.name[1]
-        spp.code <- header2$spp.code[1]
-        state.country <- header2$state.country[1]
-        spp <- header2$spp[1]
-        elev <- header2$elev[1]
-        lat <- header2$lat[1]
-        long <- header2$long[1]
-        lead.invs <- header2$lead.invs[1]
-        comp.date <- header2$comp.date[1]
-        lat.long <- ifelse(nchar(long) > 5, paste0(lat, long),
-                           paste(lat, long, sep=" "))
-        yrs <- paste(header2$first.yr[1], header2$last.yr[1], sep=" ")
+        header2 <- vapply(lapply(header, as.character), "[", character(1), 1)
+        stopifnot(!is.na(header2), Encoding(header2) != "bytes")
+        header2["lat.long"] <- if (nchar(header2["long"]) > 5) {
+            paste0(header2["lat"], header2["long"])
+        } else {
+            paste(header2["lat"], header2["long"], sep=" ")
+        }
+        header2["yrs"] <-
+            paste(header2["first.yr"], header2["last.yr"], sep=" ")
 
         field.name <-
             c("site.id", "site.name", "spp.code", "state.country", "spp",
@@ -62,19 +60,23 @@
         for (i in seq_along(field.name)) {
             this.name <- field.name[i]
             this.width <- field.width[i]
-            this.var <- get(this.name)
+            this.var <- header2[this.name]
             this.nchar <- nchar(this.var)
             if (this.nchar > this.width) {
-                assign(this.name, substr(this.var, 1, this.width))
+                header2[this.name] <- substr(this.var, 1, this.width)
             } else if (this.nchar < this.width) {
-                assign(this.name, encodeString(this.var, width = this.width))
+                header2[this.name] <-
+                    encodeString(this.var, width = this.width)
             }
         }
 
-        hdr1 <- paste0(site.id, "   ", site.name, spp.code)
-        hdr2 <- paste0(site.id, "   ", state.country, spp, elev, "  ",
-                       lat.long, "          ", yrs)
-        hdr3 <- paste0(site.id, "   ", lead.invs, comp.date)
+        hdr1 <- paste0(header2["site.id"], "   ", header2["site.name"],
+                       header2["spp.code"])
+        hdr2 <- paste0(header2["site.id"], "   ", header2["state.country"],
+                       header2["spp"], header2["elev"], "  ",
+                       header2["lat.long"], "          ", header2["yrs"])
+        hdr3 <- paste0(header2["site.id"], "   ", header2["lead.invs"],
+                       header2["comp.date"])
         hdr <- c(hdr1, hdr2, hdr3)
     }
 
@@ -83,7 +85,7 @@
     decades <- unique(decades.vec)
     n.decades <- length(decades)
     ## 1-6
-    crn.name <- names(crn2)[1]
+    crn.name <- cnames[1]
     crn.width <- nchar(crn.name)
     ## If crn.width > 6, truncate
     if (crn.width > 6) {
@@ -125,7 +127,7 @@
     ## Finish last decade with 9990 as NA and 0 as samp depth.
     dec.str[i] <- paste0(dec.str[i],
                          paste(rep("9990  0", 10-n.yrs), collapse=""))
-    if (length(header2) > 0) {
+    if (length(header) > 0) {
         dec.str <- c(hdr, dec.str)
     }
     cat(dec.str, file = fname, sep = "\n", append=append)
